import React, { useEffect } from 'react';
import PropTypes from 'prop-types';
import "./tableofcontents.css";

const parse = (regex, source) => {
    let tags = [];
    let m;
    // console.log("Match", regex.exec(source));
    while ((m = regex.exec(source)) !== null) {
        // This is necessary to avoid infinite loops with zero-width matches
        if (m.index === regex.lastIndex) {
            regex.lastIndex++;
        }
        
        // The result can be accessed through the `m`-variable.
        tags.push({ level: m[1], content: m[2] });
    }
    
    return tags;
}
const getTags = (replaceRegex, source) => ({
    markdown: function(){
        const regex = /(#{1,5})+[^ ](.*)\n/gm;
        return parse(regex, source).map(t => ({ level: t.level.length, content: t.content.replace(new RegExp(replaceRegex), "") }));
    },
    html: function(){
        const regex = /<[hH](\d)(?:.*)?>(.+)<\/[hH]\1>/gm;
        return parse(regex, source);
    },
});

const TableOfContents = ({source, type, contentType, className, replaceRegex }) => {

    const items = [
        <li>item1</li>,
        <li>item2</li>
    ];
    const tags = getTags(replaceRegex, source)[contentType]().map((t,i) => <li key={i} className={`level${t.level} ml-${t.level} b-${t.level}`}>{t.content}</li>);

    return type == "unordered" ? 
        <ol className={`bc_tableofcontents ${className}`}>{tags}</ol> 
        : 
        <ul className={`bc_tableofcontents ${className}`}>{tags}</ul>;

};

TableOfContents.propTypes = {
	source: PropTypes.oneOfType([
        PropTypes.string,
        PropTypes.object,
    ]),
    type: PropTypes.string,
    className: PropTypes.string,
    replaceRegex: PropTypes.string,
    contentType: PropTypes.string,
};
TableOfContents.defaultProps = {
	source: null,
	type: "ordered",
	replaceRegex: '(:[a-z]+:)*',
	contentType: "markdown",
	className: "",
};
export default TableOfContents;